#
# spec file for package plasma-pass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define plasma6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           plasma-pass
Version:        1.2.2
Release:        1.2
Summary:        Plasma widget for the pass password manager
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma-pass/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma-pass/%{name}-%{version}.tar.xz.sig
Source2:        plasma-pass.keyring
%endif
# PATCH-FIX-UPSTREAM
Patch0:         0001-port-to-plasma-6.patch
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(Plasma) >= %{plasma6_version}
BuildRequires:  cmake(Plasma5Support) >= %{plasma6_version}
BuildRequires:  cmake(QGpgmeQt6)
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  pkgconfig(liboath)
Recommends:     password-store

%description
Plasma Pass is a Plasma widget to access, display and copy passwords
generated and stored by the "pass" password manager.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%fdupes %{buildroot}

%files
%license LICENSES/*
%doc README.md
%{_kf6_debugdir}/plasma-pass.categories
%{_kf6_plasmadir}/plasmoids/org.kde.plasma.pass/
%dir %{_kf6_qmldir}/org/kde/plasma/private
%{_kf6_qmldir}/org/kde/plasma/private/plasmapass/
%{_kf6_appstreamdir}/org.kde.plasma.pass.appdata.xml

%files lang -f %{name}.lang

%changelog
* Fri Aug 30 2024 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to port to Plasma 6, which fixes an issue
  with the package being non-installable because it was half-ported
  and qt6qmlimport(org.kde.plasma.components.2) isn't provided by
  any package:
  * 0001-port-to-plasma-6.patch
* Fri Mar 22 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.2.2
  * Build fixes for Plasma 6
- Drop patch, no longer needed:
  * 0001-Fix-build-Qt-5.12.patch
* Wed Jan  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Fix installation with plasma-framework 5.89.
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%files section. plasma-framework >= 5.84 doesn't install
  desktop files in %%_kf5_servicesdir anymore.
* Fri Mar  5 2021 Michal Hlavac <miso@hlavki.eu>
- Update to 1.2.0
  * Add support for OTP codes
- Remove 0001-Fix-build-against-Qt-5.15.patch
  * Fixed upstream
- Add patch 0001-Fix-build-Qt-5.12.patch
  * Fix build for Qt 5.12 and lower
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Fix-build-against-Qt-5.15.patch
* Fri Dec  6 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.1.0
  * Delay filtering after user paused typing (kde#411815)
* Wed Feb 27 2019 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Wed Feb 27 2019 Luca Beltrame <lbeltrame@kde.org>
- Initial package
